@@ -1,5 +1,5 @@
 package Pod::Elemental::Command;
-our $VERSION = '0.092920';
+our $VERSION = '0.092930';
 
 
 use Moose::Role;
@@ -20,13 +20,13 @@ sub as_pod_string {
 
 sub as_debug_string {
   my ($self) = @_;
-  return sprintf '=%s', $self->command;
+  my $str = $self->_summarize_string($self->content);
+  return sprintf '=%s %s', $self->command, $str;
 }
 
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -35,11 +35,11 @@ Pod::Elemental::Command - a =command paragraph
 
 =head1 VERSION
 
-version 0.092920
+version 0.092930
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -48,6 +48,5 @@ This software is copyright (c) 2009 by Ricardo SIGNES.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
