@@ -1,5 +1,5 @@
 package Pod::Elemental::Element::Generic::Text;
-our $VERSION = '0.092920';
+our $VERSION = '0.092930';
 
 
 use Moose;
@@ -8,14 +8,9 @@ with 'Pod::Elemental::Flat';
 
 use namespace::autoclean;
 
-sub as_debug_string {
-  return '(Generic Text)';
-}
-
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -24,11 +19,11 @@ Pod::Elemental::Element::Generic::Text - a POD text or verbatim element
 
 =head1 VERSION
 
-version 0.092920
+version 0.092930
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -37,6 +32,5 @@ This software is copyright (c) 2009 by Ricardo SIGNES.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
