@@ -1,5 +1,5 @@
 package Pod::Elemental::Element::Pod5::Verbatim;
-our $VERSION = '0.092920';
+our $VERSION = '0.092930';
 
 
 use Moose;
@@ -9,14 +9,9 @@ with    'Pod::Elemental::Autoblank';
 
 use namespace::autoclean;
 
-sub as_debug_string {
-  return '(Pod5 Verbatim)';
-}
-
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -25,11 +20,11 @@ Pod::Elemental::Element::Pod5::Verbatim - a POD verbatim element
 
 =head1 VERSION
 
-version 0.092920
+version 0.092930
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -38,6 +33,5 @@ This software is copyright (c) 2009 by Ricardo SIGNES.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
